@@ -3,7 +3,7 @@ use warnings;
 
 package Number::Format::SouthAsian;
 BEGIN {
-  $Number::Format::SouthAsian::VERSION = '0.03';
+  $Number::Format::SouthAsian::VERSION = '0.04';
 }
 
 use Carp;
@@ -15,7 +15,7 @@ Number::Format::SouthAsian - format numbers in the South Asian style
 
 =head1 VERSION
 
-version 0.03
+version 0.04
 
 =head1 SYNOPSIS
 
@@ -110,18 +110,15 @@ my %zeroes_to_words = (
     '17' => 'shankh',
     '19' => 'maha shankh',
     '21' => 'ank',
-###########################################################
-#### not supported at 64 bit, disabling for now...
-###########################################################
-#   '23' => 'jald',
-#   '25' => 'madh',
-#   '27' => 'paraardha',
-#   '29' => 'ant',
-#   '31' => 'maha ant',
-#   '33' => 'shisht',
-#   '35' => 'singhar',
-#   '37' => 'maha singhar',
-#   '39' => 'adant singhar',
+    '23' => 'jald',
+    '25' => 'madh',
+    '27' => 'paraardha',
+    '29' => 'ant',
+    '31' => 'maha ant',
+    '33' => 'shisht',
+    '35' => 'singhar',
+    '37' => 'maha singhar',
+    '39' => 'adant singhar',
 );
 
 sub _format_number_wordy {
@@ -136,7 +133,7 @@ sub _format_number_wordy {
     if ($number =~ m/^ ( \d+ (?: [.]\d+)?) e[+] (\d+) $/msx) {
         my ($mantissa, $exponent) = ($1, $2);
 
-        if ($mantissa < 1) {
+        if ($mantissa <= 1) {
             $zeroes = $exponent;
         }
         else {
